/*---------------------------------------------------------------
 *	micro:bitのデバイスIDの表示(μT-Kernel 3.0用)
 *
 *	Copyright (C) 2022-2024 by T3 WG of TRON Forum
 *---------------------------------------------------------------*/
#include <tk/tkernel.h>
#include <tm/tmonitor.h>

//-------- ボードIDの取得 ---------------------------------------
#define	NRF5_FICR_BASE	0x10000000
#define	DEVICEID_0		0x060		// Device identifier 0
#define	DEVICEID_1		0x064		// Device identifier 1

// メインボード用micro:bitの実際のデバイスID
const W main_devid0 = 0x01234567;	// (★要設定★)
const W main_devid1 = 0x89abcdef;	// (★要設定★)

W devid0, devid1;					// 実行中のmicro:bitのデバイスID

// 自分自身がメインボードの場合にTRUEを返す関数(※B)
LOCAL BOOL is_main_board(){
	return(devid0 == main_devid0 && devid1 == main_devid1);
}

// ボードのデバイスIDを取得してコンソールに表示
LOCAL void get_device_id(void)
{
	devid0 = in_w(NRF5_FICR_BASE + DEVICEID_0);	// DEVICE[0]の読み出し(※A)
	devid1 = in_w(NRF5_FICR_BASE + DEVICEID_1);	// DEVICE[1]の読み出し(※A)

	tm_printf("This devid_0_1: %08x_%08x\n", devid0, devid1);
	tm_printf("Main devid_0_1: %08x_%08x\n", main_devid0, main_devid1);
	if(is_main_board())
		tm_printf("This is MAIN board, P0TX_P1RX\n\n");
	else
		tm_printf("This is  SUB board, P1TX_P0RX\n\n");
}	

//---------------------------------------------------------------
EXPORT void usermain( void ){

	get_device_id();		// デバイスIDの取得と表示
	tk_slp_tsk(TMO_FEVR);	// 永久待ち、以下は実行しない
}
